@@ -12,12 +12,20 @@ import (
 type Documentation struct{}
 
 func (r Documentation) ValidOptions() []*formatOption {
-	return []*formatOption{}
+	return []*formatOption{
+		{name: foSort},
+	}
 }
 
 func (r Documentation) Output(w io.Writer, results <-chan []resource.TestResult,
-	startTime time.Time, outConfig util.OutputConfig) (exitCode int) {
+	outConfig util.OutputConfig) (exitCode int) {
+	includeRaw := !util.IsValueInList(foExcludeRaw, outConfig.FormatOptions)
 
+	sort := util.IsValueInList(foSort, outConfig.FormatOptions)
+	results = getResults(results, sort)
+
+	var startTime time.Time
+	var endTime time.Time
 	testCount := 0
 	var failedOrSkipped [][]resource.TestResult
 	var skipped, failed int
@@ -29,15 +37,21 @@ func (r Documentation) Output(w io.Writer, results <-chan []resource.TestResult,
 			fmt.Fprint(w, header)
 		}
 		for _, testResult := range resultGroup {
+			if startTime.IsZero() || testResult.StartTime.Before(startTime) {
+				startTime = testResult.StartTime
+			}
+			if endTime.IsZero() || testResult.EndTime.After(endTime) {
+				endTime = testResult.EndTime
+			}
 			switch testResult.Result {
 			case resource.SUCCESS:
-				fmt.Fprintln(w, humanizeResult(testResult))
+				fmt.Fprintln(w, humanizeResult(testResult, false, includeRaw))
 			case resource.SKIP:
-				fmt.Fprintln(w, humanizeResult(testResult))
+				fmt.Fprintln(w, humanizeResult(testResult, false, includeRaw))
 				failedOrSkippedGroup = append(failedOrSkippedGroup, testResult)
 				skipped++
 			case resource.FAIL:
-				fmt.Fprintln(w, humanizeResult(testResult))
+				fmt.Fprintln(w, humanizeResult(testResult, false, includeRaw))
 				failedOrSkippedGroup = append(failedOrSkippedGroup, testResult)
 				failed++
 			}
@@ -49,9 +63,9 @@ func (r Documentation) Output(w io.Writer, results <-chan []resource.TestResult,
 	}
 
 	fmt.Fprint(w, "\n\n")
-	fmt.Fprint(w, failedOrSkippedSummary(failedOrSkipped))
+	fmt.Fprint(w, failedOrSkippedSummary(failedOrSkipped, includeRaw))
 
-	fmt.Fprint(w, summary(startTime, testCount, failed, skipped))
+	fmt.Fprint(w, summary(startTime, endTime, testCount, failed, skipped))
 	if failed > 0 {
 		return 1
 	}
