@@ -24,8 +24,7 @@ func (r Json) ValidOptions() []*formatOption {
 func (r Json) Output(w io.Writer, results <-chan []resource.TestResult,
 	outConfig util.OutputConfig) (exitCode int) {
 
-	var pretty bool
-	pretty = util.IsValueInList(foPretty, outConfig.FormatOptions)
+	var pretty bool = util.IsValueInList(foPretty, outConfig.FormatOptions)
 	includeRaw := !util.IsValueInList(foExcludeRaw, outConfig.FormatOptions)
 
 	sort := util.IsValueInList(foSort, outConfig.FormatOptions)
