@@ -47,7 +47,7 @@ func (g *Group) GetGroupname() string {
 }
 
 func (g *Group) Validate(sys *system.System) []TestResult {
-	ctx := context.WithValue(context.Background(), "id", g.ID())
+	ctx := context.WithValue(context.Background(), idKey{}, g.ID())
 	skip := g.Skip
 	sysgroup := sys.NewGroup(ctx, g.GetGroupname(), sys, util.Config{})
 
