@@ -26,7 +26,7 @@ type ResourceType generic.Type
 type ResourceTypeMap map[string]*ResourceType
 
 func (r ResourceTypeMap) AppendSysResource(sr string, sys *system.System, config util.Config) (*ResourceType, error) {
-	ctx := context.WithValue(context.Background(), "id", sr)
+	ctx := context.WithValue(context.Background(), idKey{}, sr)
 	sysres := sys.NewResourceType(ctx, sr, sys, config)
 	res, err := NewResourceType(sysres, config)
 	if err != nil {
@@ -41,13 +41,13 @@ func (r ResourceTypeMap) AppendSysResource(sr string, sys *system.System, config
 }
 
 func (r ResourceTypeMap) AppendSysResourceIfExists(sr string, sys *system.System) (*ResourceType, system.ResourceType, bool, error) {
-	ctx := context.WithValue(context.Background(), "id", sr)
+	ctx := context.WithValue(context.Background(), idKey{}, sr)
 	sysres := sys.NewResourceType(ctx, sr, sys, util.Config{})
 	res, err := NewResourceType(sysres, util.Config{})
 	if err != nil {
 		return nil, nil, false, err
 	}
-	if e, _ := sysres.Exists(); e != true {
+	if e, _ := sysres.Exists(); !e {
 		return res, sysres, false, nil
 	}
 	if old_res, ok := r[res.ID()]; ok {
