@@ -3,7 +3,7 @@
 
 package system
 
-import "github.com/aelsabbahy/goss/util"
+import "github.com/goss-org/goss/util"
 
 const windowsShell string = "cmd"
 
