@@ -1,6 +1,10 @@
 package system
 
-import "github.com/goss-org/goss/util"
+import (
+	"context"
+
+	"github.com/goss-org/goss/util"
+)
 
 type Gossfile interface {
 	Path() string
@@ -20,6 +24,6 @@ func (g *DefGossfile) Exists() (bool, error) {
 	return false, nil
 }
 
-func NewDefGossfile(path string, system *System, config util.Config) Gossfile {
+func NewDefGossfile(_ context.Context, path string, system *System, config util.Config) Gossfile {
 	return &DefGossfile{path: path}
 }
