@@ -2,6 +2,7 @@ package system
 
 import (
 	"bufio"
+	"context"
 	"fmt"
 	"os"
 	"regexp"
@@ -17,7 +18,7 @@ type ServiceUpstart struct {
 var upstartEnabled = regexp.MustCompile(`^\s*start on`)
 var upstartDisabled = regexp.MustCompile(`^manual`)
 
-func NewServiceUpstart(service string, system *System, config util.Config) Service {
+func NewServiceUpstart(_ context.Context, service string, system *System, config util.Config) Service {
 	return &ServiceUpstart{service: service}
 }
 
@@ -77,3 +78,7 @@ func (s *ServiceUpstart) Running() (bool, error) {
 	}
 	return false, nil
 }
+func (s *ServiceUpstart) RunLevels() ([]string, error) {
+	sysv := &ServiceInit{service: s.service}
+	return sysv.RunLevels()
+}
